API Reference
=============

Performance Estimator of Codes On Surfaces (PECOS) a framework for developing, studying, and evaluating quantum error-correcting codes.

.. autosummary::
   :toctree: _autosummary
   :recursive:

   pecos

Modules
^^^^^^^

.. autosummary::
   :toctree: _autosummary
   :recursive:

   pecos.circuits
   pecos.classical_interpreters
   pecos.decoders
   pecos.engines
   pecos.error_models
   pecos.errors
   pecos.foreign_objects
   pecos.machines
   pecos.misc
   pecos.op_processors
   pecos.qeccs
   pecos.reps
   pecos.simulators
   pecos.tools
